/**
 * Calculates the Heart Rate Reserve (HRR) range based on age, resting heart rate, and exercise intensity. Karvonen Formula THR = [(MHR - RHR) x %Intensity] + RHR
 * @param age - The age of the person in years.
 * @param restingHeartRate - The resting heart rate in beats per minute.
 * @param intensity - The intensity of the exercise ("very_light", "light", "moderate", "hard", "very_hard").
 * @returns An object containing the HRR range.
 * @throws Error if age, resting heart rate, or intensity is invalid.
 */
export declare function calculateHRRRange(age: number, restingHeartRate: number, intensity: "very_light" | "light" | "moderate" | "hard" | "very_hard"): {
    hrrMin: number;
    hrrMax: number;
};
